@@ -62,11 +62,10 @@ from robotoff.prediction.ocr.dataclass import OCRParsingException
 from robotoff.products import get_product_dataset_etag
 from robotoff.spellcheck import SPELLCHECKERS, Spellchecker
 from robotoff.taxonomy import is_prefixed_value, match_taxonomized_value
-from robotoff.types import PredictionType
+from robotoff.types import ElasticSearchIndex, JSONType, PredictionType
 from robotoff.utils import get_image_from_url, get_logger, http_session
 from robotoff.utils.i18n import TranslationStore
 from robotoff.utils.text import get_tag
-from robotoff.utils.types import JSONType
 from robotoff.workers.queues import enqueue_in_job, enqueue_job, high_queue, low_queue
 from robotoff.workers.tasks import (
     delete_product_insights_job,
@@ -318,7 +317,7 @@ class IngredientSpellcheckResource:
                 resp.media = {"status": "not_found"}
                 return
 
-        index_name = req.get_param("index", default="product_all")
+        index_name = req.get_param("index", default=ElasticSearchIndex.product.name)
         confidence = req.get_param_as_float("confidence", default=0.5)
         pipeline = req.get_param_as_list("pipeline") or None
         safe = req.get_param_as_bool("safe", blank_as_true=False)
@@ -712,8 +711,7 @@ class ImageLogoSearchResource:
             join_image_model = True
 
         if barcode is not None:
-            where_clauses.append(ImageModel.barcode == barcode)
-            join_image_model = True
+            where_clauses.append(LogoAnnotation.barcode == barcode)
 
         if type_ is not None:
             where_clauses.append(LogoAnnotation.annotation_type == type_)
@@ -824,12 +822,11 @@ class ImageLogoResetResource:
             logo.save()
 
             if annotation_type in ("brand", "label"):
-                barcode = logo.image_prediction.image.barcode
                 prediction_deleted = (
                     Prediction.delete()
                     .where(
                         # Speed-up filtering by providing additional filters
-                        Prediction.barcode == barcode,
+                        Prediction.barcode == logo.barcode,
                         Prediction.type == annotation_type,
                         Prediction.predictor == "universal-logo-detector",
                         Prediction.data["logo_id"] == str(logo.id),
@@ -839,7 +836,7 @@ class ImageLogoResetResource:
                 insights_deleted = (
                     ProductInsight.delete()
                     .where(
-                        ProductInsight.barcode == barcode,
+                        ProductInsight.barcode == logo.barcode,
                         ProductInsight.type == annotation_type,
                         # never delete annotated insights
                         ProductInsight.annotation.is_null(),
@@ -1192,24 +1189,31 @@ class DumpResource:
         keep_types: list[str] = req.get_param_as_list(
             "insight_types", required=False, default=[]
         )[:10]
-
         barcode = req.get_param("barcode")
         annotated = req.get_param_as_bool("annotated", blank_as_true=False)
         value_tag = req.get_param("value_tag")
+        count = req.get_param_as_int("count", min_value=0, max_value=10_000)
 
-        insights_iter = get_insights(
+        get_insights_ = functools.partial(
+            get_insights,
             barcode=barcode,
             keep_types=keep_types,
             annotated=annotated,
             value_tag=value_tag,
-            limit=None,
         )
+        insight_count: int = get_insights_(count=True)  # type: ignore
+        if insight_count > 10_000 and count is None:
+            raise falcon.HTTPBadRequest(
+                description=f"more than 10 000 insights matching criteria (here: {insight_count}), "
+                "use more specific criteria or use count parameter"
+            )
 
+        insights_iter = get_insights_(limit=count, as_dict=True)
         writer = None
 
         with tempfile.TemporaryFile("w+", newline="") as temp_f:
-            for insight in insights_iter:
-                serial = orjson.loads(orjson.dumps(insight.to_dict()))
+            for insight_dict in insights_iter:
+                serial = orjson.loads(orjson.dumps(insight_dict))
 
                 if writer is None:
                     writer = csv.DictWriter(temp_f, fieldnames=serial.keys())
@@ -1459,6 +1463,7 @@ api.add_route("/api/v1/insights/detail/{insight_id:uuid}", ProductInsightDetail(
 api.add_route("/api/v1/insights", InsightCollection())
 api.add_route("/api/v1/insights/random", RandomInsightResource())
 api.add_route("/api/v1/insights/annotate", AnnotateInsightResource())
+api.add_route("/api/v1/insights/dump", DumpResource())
 api.add_route("/api/v1/predict/ingredients/spellcheck", IngredientSpellcheckResource())
 api.add_route("/api/v1/predict/nutrient", NutrientPredictorResource())
 api.add_route("/api/v1/predict/ocr_insights", OCRInsightsPredictorResource())
@@ -1486,7 +1491,6 @@ api.add_route("/api/v1/questions/popular", PopularQuestionsResource())
 api.add_route("/api/v1/questions/unanswered", UnansweredQuestionCollection())
 api.add_route("/api/v1/status", StatusResource())
 api.add_route("/api/v1/health", HealthResource())
-api.add_route("/api/v1/dump", DumpResource())
 api.add_route("/api/v1/users/statistics/{username}", UserStatisticsResource())
 api.add_route("/api/v1/predictions", PredictionCollection())
 api.add_route("/api/v1/images/prediction/collection", ImagePredictionCollection())
