@@ -153,7 +153,7 @@ def categorize(barcode: str, deepest_only: bool = False) -> None:
 
     if predictions:
         for prediction in predictions:
-            print(f"{prediction.value_tag}: {prediction.data['confidence']}")
+            print(f"{prediction.value_tag}: {prediction.confidence}")
     else:
         print(f"Nothing predicted for product {barcode}")
 
@@ -392,7 +392,10 @@ def run_object_detection_model(
                         & (ImagePrediction.model_name == model_name.value)
                     ),
                 )
-                .where(ImagePrediction.model_name.is_null())
+                .where(
+                    ImagePrediction.model_name.is_null()
+                    & (ImageModel.deleted == False)  # noqa: E712
+                )
                 .tuples()
             )
             if limit:
@@ -588,26 +591,22 @@ def export_logos(
 ) -> None:
     """Export all information about logo in DB necessary to generate logo
     crops."""
-    from robotoff.models import ImageModel, ImagePrediction, LogoAnnotation, db
+    from robotoff.models import LogoAnnotation, db
     from robotoff.utils import dump_jsonl
 
     with db:
-        query = (
-            LogoAnnotation.select(
-                LogoAnnotation.id,
-                LogoAnnotation.index,
-                LogoAnnotation.bounding_box,
-                LogoAnnotation.score,
-                LogoAnnotation.annotation_type,
-                LogoAnnotation.annotation_value,
-                LogoAnnotation.annotation_value_tag,
-                LogoAnnotation.taxonomy_value,
-                LogoAnnotation.username,
-                ImageModel.image_id,
-                ImageModel.barcode,
-            )
-            .join(ImagePrediction)
-            .join(ImageModel)
+        query = LogoAnnotation.select(
+            LogoAnnotation.id,
+            LogoAnnotation.index,
+            LogoAnnotation.bounding_box,
+            LogoAnnotation.score,
+            LogoAnnotation.annotation_type,
+            LogoAnnotation.annotation_value,
+            LogoAnnotation.annotation_value_tag,
+            LogoAnnotation.taxonomy_value,
+            LogoAnnotation.username,
+            LogoAnnotation.source_image,
+            LogoAnnotation.barcode,
         )
         dump_jsonl(output, query.dicts().iterator())
 
