@@ -15,21 +15,19 @@ from robotoff.elasticsearch import get_es_client
 from robotoff.insights.annotate import UPDATED_ANNOTATION_RESULT, annotate
 from robotoff.insights.importer import import_insights
 from robotoff.logo_label_type import LogoLabelType
-from robotoff.models import (
-    ImageModel,
-    ImagePrediction,
-    LogoAnnotation,
-    LogoConfidenceThreshold,
-    LogoEmbedding,
-)
+from robotoff.models import LogoAnnotation, LogoConfidenceThreshold, LogoEmbedding
 from robotoff.models import Prediction as PredictionModel
 from robotoff.models import ProductInsight, db
 from robotoff.off import OFFAuthentication
 from robotoff.prediction.types import Prediction
 from robotoff.slack import NotifierFactory
-from robotoff.types import ElasticSearchIndex, InsightImportResult, PredictionType
+from robotoff.types import (
+    ElasticSearchIndex,
+    InsightImportResult,
+    JSONType,
+    PredictionType,
+)
 from robotoff.utils import get_logger
-from robotoff.utils.types import JSONType
 
 logger = get_logger(__name__)
 
@@ -341,11 +339,7 @@ def import_logo_insights(
         )
         & (~(PredictionModel.data["is_annotation"].cast("bool") == True))  # noqa: E712
         # Add a filter on barcode to speed-up filtering
-        & (
-            PredictionModel.barcode.in_(
-                [logo.image_prediction.image.barcode for logo in logos]
-            )
-        )
+        & (PredictionModel.barcode.in_([logo.barcode for logo in logos]))
     ).execute()
     predictions = predict_logo_predictions(selected_logos, logo_probs)
     import_result = import_insights(predictions, server_domain)
@@ -368,20 +362,19 @@ def generate_insights_from_annotated_logos(
             logo_value=logo.taxonomy_value,
             automatic_processing=False,  # we're going to apply it immediately
             data={
-                "confidence": 1.0,
                 "logo_id": logo.id,
                 "bounding_box": logo.bounding_box,
                 "username": logo.username,
                 "is_annotation": True,  # it's worth restating it
             },
+            confidence=1.0,
         )
 
         if prediction is None:
             continue
 
-        image = logo.image_prediction.image
-        prediction.barcode = image.barcode
-        prediction.source_image = image.source_image
+        prediction.barcode = logo.barcode
+        prediction.source_image = logo.source_image
         predictions.append(prediction)
 
     import_result = import_insights(predictions, server_domain)
@@ -425,17 +418,16 @@ def predict_logo_predictions(
         prediction = generate_prediction(
             logo_type=label[0],
             logo_value=label[1],
+            confidence=max_prob,
             data={
-                "confidence": max_prob,
                 "logo_id": logo.id,
                 "bounding_box": logo.bounding_box,
             },
         )
 
         if prediction is not None:
-            image = logo.image_prediction.image
-            prediction.barcode = image.barcode
-            prediction.source_image = image.source_image
+            prediction.barcode = logo.barcode
+            prediction.source_image = logo.source_image
             predictions.append(prediction)
 
     return predictions
@@ -445,14 +437,14 @@ def generate_prediction(
     logo_type: str,
     logo_value: Optional[str],
     data: dict,
+    confidence: float,
     automatic_processing: Optional[bool] = False,
 ) -> Optional[Prediction]:
     """Generate a Prediction from a logo.
 
     The Prediction may either be created after the annotation of the logo by
-    a human (in which case `automatic_processing` is True), or by infering the
-    logo value from nearest neighbor labels (in which case
-    `automatic_processing` is False).
+    a human (in which case the insight should be annotated right after
+    creation), or by infering the logo value from nearest neighbor labels.
 
     Currently, only brand and label logo types are supported: None is returned
     if the logo type is different, or if the logo_value is None.
@@ -478,6 +470,7 @@ def generate_prediction(
         automatic_processing=automatic_processing,
         predictor="universal-logo-detector",
         data=data,
+        confidence=confidence,
     )
 
 
@@ -506,15 +499,8 @@ def refresh_nearest_neighbors(day_offset: int = 7, batch_size: int = 500):
     for logo_id_batch in chunked(logo_ids, batch_size):
         with db.atomic():
             logo_embeddings = list(
-                LogoEmbedding.select(
-                    LogoEmbedding,
-                    LogoAnnotation,
-                    ImageModel.barcode,
-                    ImageModel.source_image,
-                )
+                LogoEmbedding.select(LogoEmbedding, LogoAnnotation)
                 .join(LogoAnnotation)
-                .join(ImagePrediction)
-                .join(ImageModel)
                 .where(LogoEmbedding.logo_id.in_(logo_id_batch))
             )
             try:
